@@ -16,7 +16,8 @@ HOST = os.environ.get('RIAK_TEST_HOST', 'localhost')
 HTTP_HOST = os.environ.get('RIAK_TEST_HTTP_HOST', HOST)
 PB_HOST = os.environ.get('RIAK_TEST_PB_HOST', HOST)
 HTTP_PORT = int(os.environ.get('RIAK_TEST_HTTP_PORT', '8098'))
-PB_PORT = int(os.environ.get('RIAK_TEST_HTTP_PORT', '8087'))
+PB_PORT = int(os.environ.get('RIAK_TEST_PB_PORT', '8087'))
+SKIP_SEARCH = int(os.environ.get('SKIP_SEARCH', '0'))
 
 class NotJsonSerializable(object):
 
@@ -147,6 +148,25 @@ class BaseTestCase(object):
         self.assertFalse(bucket.get_allow_multiples())
         self.assertEqual(bucket.get_n_val(), 2)
 
+    def test_rw_settings(self):
+        bucket = self.client.bucket('rwsettings')
+        self.assertEqual(bucket.get_r(), "default")
+        self.assertEqual(bucket.get_w(), "default")
+        self.assertEqual(bucket.get_dw(), "default")
+        self.assertEqual(bucket.get_rw(), "default")
+
+        bucket.set_w(1)
+        self.assertEqual(bucket.get_w(), 1)
+
+        bucket.set_r("quorum")
+        self.assertEqual(bucket.get_r(), "quorum")
+
+        bucket.set_dw("all")
+        self.assertEqual(bucket.get_dw(), "all")
+
+        bucket.set_rw("one")
+        self.assertEqual(bucket.get_rw(), "one")
+
     def test_siblings(self):
         # Set up the bucket, clear any existing object...
         bucket = self.client.bucket('multiBucket')
@@ -205,7 +225,7 @@ class BaseTestCase(object):
             .run()
         self.assertEqual(result, [2])
 
-    def testJavascriptNamedMap(self):
+    def test_javascript_named_map(self):
         # Create the object...
         bucket = self.client.bucket("bucket")
         bucket.new("foo", 2).store()
@@ -216,7 +236,7 @@ class BaseTestCase(object):
             .run()
         self.assertEqual(result, [2])
 
-    def test_javascript_source_mapReduce(self):
+    def test_javascript_source_map_reduce(self):
         # Create the object...
         bucket = self.client.bucket("bucket")
         bucket.new("foo", 2).store()
@@ -228,9 +248,9 @@ class BaseTestCase(object):
             .add("bucket", "bar") \
             .add("bucket", "baz") \
             .map("function (v) { return [1]; }") \
-            .reduce("function(v) { return v.length; } ") \
+            .reduce("Riak.reduceSum") \
             .run()
-        self.assertEqual(result, 3)
+        self.assertEqual(result, [3])
 
     def test_javascript_named_map_reduce(self):
         # Create the object...
@@ -248,7 +268,7 @@ class BaseTestCase(object):
             .run()
         self.assertEqual(result, [9])
 
-    def testJavascriptBucketMapReduce(self):
+    def test_javascript_bucket_map_reduce(self):
         # Create the object...
         bucket = self.client.bucket("bucket_%s" % self.randint())
         bucket.new("foo", 2).store()
@@ -328,6 +348,28 @@ class BaseTestCase(object):
         results = obj.link("bucket", "tag").run()
         self.assertEqual(len(results), 1)
 
+    def test_search_integration(self):
+        if SKIP_SEARCH:
+            return True
+        # Create some objects to search across...
+        bucket = self.client.bucket("searchbucket")
+        bucket.new("one", {"foo":"one", "bar":"red"}).store()
+        bucket.new("two", {"foo":"two", "bar":"green"}).store()
+        bucket.new("three", {"foo":"three", "bar":"blue"}).store()
+        bucket.new("four", {"foo":"four", "bar":"orange"}).store()
+        bucket.new("five", {"foo":"five", "bar":"yellow"}).store()
+
+       # Run some operations...
+        results = self.client.search("searchbucket", "foo:one OR foo:two").run()
+        if (len(results) == 0):
+            print "\n\nNot running test \"testSearchIntegration()\".\n"
+            print "Please ensure that you have installed the Riak Search hook on bucket \"searchbucket\" by running \"bin/search-cmd install searchbucket\".\n\n"
+            return
+        self.assertEqual(len(results), 2)
+        results = self.client.search("searchbucket", "(foo:one OR foo:two OR foo:three OR foo:four) AND (NOT bar:green)").run()
+        self.assertEqual(len(results), 3)
+
+
 class RiakPbcTransportTestCase(BaseTestCase, unittest.TestCase):
 
     def setUp(self):
